@@ -134,7 +134,7 @@ def tests(session):
             # itself does not get upgraded
             pytest_requirements = []
             if not pytest_version_requirement.startswith("pytest"):
-                pytest_version_requirement = "pytest{}".format(pytest_version_requirement)
+                pytest_version_requirement = f"pytest{pytest_version_requirement}"
             pytest_requirements.append(pytest_version_requirement)
             if pytest_version_requirement.startswith("pytest~=6"):
                 pytest_requirements.append("pytest-subtests<0.7.0")
@@ -172,10 +172,10 @@ def tests(session):
     args = [
         "--rootdir",
         str(REPO_ROOT),
-        "--log-file={}".format(RUNTESTS_LOGFILE),
+        f"--log-file={RUNTESTS_LOGFILE}",
         "--log-file-level=debug",
         "--show-capture=no",
-        "--junitxml={}".format(JUNIT_REPORT),
+        f"--junitxml={JUNIT_REPORT}",
         "--showlocals",
         "--strict-markers",
         "-ra",
@@ -222,7 +222,7 @@ def tests(session):
                 "--include=src/pytestskipmarkers/*,tests/*",
             ]
             if pytest_version(session) >= (6, 2):
-                cmdline.append("--fail-under={}".format(COVERAGE_FAIL_UNDER_PERCENT))
+                cmdline.append(f"--fail-under={COVERAGE_FAIL_UNDER_PERCENT}")
             session.run(*cmdline)
         finally:
             if COVERAGE_REPORT_DB.exists():
@@ -239,7 +239,7 @@ def _lint(session, rcfile, flags, paths):
     session.run("pylint", "--version")
     pylint_report_path = os.environ.get("PYLINT_REPORT")
 
-    cmd_args = ["pylint", "--rcfile={}".format(rcfile)] + list(flags) + list(paths)
+    cmd_args = ["pylint", f"--rcfile={rcfile}"] + list(flags) + list(paths)
 
     stdout = tempfile.TemporaryFile(mode="w+b")
     try:
@@ -264,8 +264,8 @@ def lint(session):
     """
     Run PyLint against Salt and it's test suite. Set PYLINT_REPORT to a path to capture output.
     """
-    session.notify("lint-code-{}".format(session.python))
-    session.notify("lint-tests-{}".format(session.python))
+    session.notify(f"lint-code-{session.python}")
+    session.notify(f"lint-tests-{session.python}")
 
 
 @nox.session(python="3", name="lint-code")
@@ -414,14 +414,15 @@ def changelog(session, draft):
 
     version = session.run(
         "python",
-        "setup.py",
-        "--version",
+        "-c",
+        'import os,sys; sys.path.insert(0, "src/"); import pytestskipmarkers; '
+        "print(pytestskipmarkers.__version__, file=sys.stdout, flush=True);",
         silent=True,
         log=False,
         stderr=None,
     ).strip()
 
-    town_cmd = ["towncrier", "build", "--version={}".format(version)]
+    town_cmd = ["towncrier", "build", f"--version={version}"]
     if draft:
         town_cmd.append("--draft")
     session.run(*town_cmd)
@@ -444,7 +445,7 @@ def release(session):
     version = session.posargs[0]
     try:
         session.log("Generating temporary %s tag", version)
-        session.run("git", "tag", "-as", version, "-m", "Release {}".format(version), external=True)
+        session.run("git", "tag", "-as", version, "-m", f"Release {version}", external=True)
         changelog(session, draft=False)
     except CommandFailed:
         session.error("Failed to generate the temporary tag")
@@ -456,16 +457,14 @@ def release(session):
             "commit",
             "-a",
             "-m",
-            "Generate Changelog for version {}".format(version),
+            f"Generate Changelog for version {version}",
             external=True,
         )
     except CommandFailed:
         session.error("Failed to generate the release changelog")
     try:
         session.log("Overwriting temporary %s tag", version)
-        session.run(
-            "git", "tag", "-fas", version, "-m", "Release {}".format(version), external=True
-        )
+        session.run("git", "tag", "-fas", version, "-m", f"Release {version}", external=True)
     except CommandFailed:
         session.error("Failed to overwrite the temporary tag")
     session.warn("Don't forget to push the newly created tag")
