@@ -47,9 +47,7 @@ def test_skipped(pytester, platform):
         )
     )
     return_value = True
-    with mock.patch(
-        "pytestskipmarkers.utils.platform.is_{}".format(platform), return_value=return_value
-    ):
+    with mock.patch(f"pytestskipmarkers.utils.platform.is_{platform}", return_value=return_value):
         res = pytester.runpytest_inprocess()
         res.assert_outcomes(skipped=1)
     res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
@@ -83,9 +81,7 @@ def test_not_skipped(pytester, platform):
         )
     )
     return_value = False
-    with mock.patch(
-        "pytestskipmarkers.utils.platform.is_{}".format(platform), return_value=return_value
-    ):
+    with mock.patch(f"pytestskipmarkers.utils.platform.is_{platform}", return_value=return_value):
         res = pytester.runpytest_inprocess()
         res.assert_outcomes(passed=1)
     res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
